<!---
Please read this!

Before opening a new issue, make sure to skim through the documentation
at http://ml.pages.km3net.de/OrcaSong
--->

### Summary

(Summarise the bug encountered concisely.)

### Environment

-  OrcaSong version:
-  Python version (`python --version`):
-  OS: (`uname -a`)

### What is the current *bug* behavior?

(What actually happens)

### What is the expected *correct* behavior?

(What you should see instead)

### Steps to reproduce

(How one can reproduce the issue - this is very important.)

### Relevant logs and/or screenshots

(Paste any relevant logs - please use code blocks (put the code between ```) to format console output, logs, and code as it's very hard to read otherwise.)

/label ~bug
